@@ -1,6 +1,7 @@
-from .enclave import Enclave
+from .enclave import Enclave, EnclavePermissions
 from .indicator import Indicator
 from .page import Page
 from .report import Report
 from .tag import Tag
-from .enum import *
\ No newline at end of file
+from .request_quota import RequestQuota
+from .enum import *
